@@ -57,3 +57,7 @@ class Dnf( Command ):
         """
         result = cls( 'clean', 'all' )()
         return result
+
+    def config_manager( cls, package ):
+        result = cls( 'config-manager', '--set-enabled', package )()
+        return result
